References
==========

.. [Gotoh1982] Gotoh, O.  An Improved Algorithm for Matching Biological Sequences.
               1982.  J. Mol. Biol. 162, 705-708

.. [NeedlemanWunsch1970] Needleman, S.  Wunsch, C.  A General Method Applicable to the
                         Search for Similarities in the Amino Acid Sequence of Two
                         Proteins.  1970.  J. Mol. Biol. 48, 443-453

.. [Warren2013] Warren, H.S. Hacker's Delight.
                2nd Edition 2013. Pearson, Westford, MA.
